# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class AppDynamicsConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_filter_regex': 'list[str]',
        'controller_name': 'str',
        'enable_app_infra_metrics': 'bool',
        'enable_backend_metrics': 'bool',
        'enable_business_trx_metrics': 'bool',
        'enable_error_metrics': 'bool',
        'enable_individual_node_metrics': 'bool',
        'enable_overall_perf_metrics': 'bool',
        'enable_rollup': 'bool',
        'enable_service_endpoint_metrics': 'bool',
        'encrypted_password': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'app_filter_regex': 'appFilterRegex',
        'controller_name': 'controllerName',
        'enable_app_infra_metrics': 'enableAppInfraMetrics',
        'enable_backend_metrics': 'enableBackendMetrics',
        'enable_business_trx_metrics': 'enableBusinessTrxMetrics',
        'enable_error_metrics': 'enableErrorMetrics',
        'enable_individual_node_metrics': 'enableIndividualNodeMetrics',
        'enable_overall_perf_metrics': 'enableOverallPerfMetrics',
        'enable_rollup': 'enableRollup',
        'enable_service_endpoint_metrics': 'enableServiceEndpointMetrics',
        'encrypted_password': 'encryptedPassword',
        'user_name': 'userName'
    }

    def __init__(self, app_filter_regex=None, controller_name=None, enable_app_infra_metrics=None, enable_backend_metrics=None, enable_business_trx_metrics=None, enable_error_metrics=None, enable_individual_node_metrics=None, enable_overall_perf_metrics=None, enable_rollup=None, enable_service_endpoint_metrics=None, encrypted_password=None, user_name=None, _configuration=None):  # noqa: E501
        """AppDynamicsConfiguration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._app_filter_regex = None
        self._controller_name = None
        self._enable_app_infra_metrics = None
        self._enable_backend_metrics = None
        self._enable_business_trx_metrics = None
        self._enable_error_metrics = None
        self._enable_individual_node_metrics = None
        self._enable_overall_perf_metrics = None
        self._enable_rollup = None
        self._enable_service_endpoint_metrics = None
        self._encrypted_password = None
        self._user_name = None
        self.discriminator = None

        if app_filter_regex is not None:
            self.app_filter_regex = app_filter_regex
        self.controller_name = controller_name
        if enable_app_infra_metrics is not None:
            self.enable_app_infra_metrics = enable_app_infra_metrics
        if enable_backend_metrics is not None:
            self.enable_backend_metrics = enable_backend_metrics
        if enable_business_trx_metrics is not None:
            self.enable_business_trx_metrics = enable_business_trx_metrics
        if enable_error_metrics is not None:
            self.enable_error_metrics = enable_error_metrics
        if enable_individual_node_metrics is not None:
            self.enable_individual_node_metrics = enable_individual_node_metrics
        if enable_overall_perf_metrics is not None:
            self.enable_overall_perf_metrics = enable_overall_perf_metrics
        if enable_rollup is not None:
            self.enable_rollup = enable_rollup
        if enable_service_endpoint_metrics is not None:
            self.enable_service_endpoint_metrics = enable_service_endpoint_metrics
        self.encrypted_password = encrypted_password
        self.user_name = user_name

    @property
    def app_filter_regex(self):
        """Gets the app_filter_regex of this AppDynamicsConfiguration.  # noqa: E501

        List of regular expressions that a application name must match (case-insensitively) in order to be ingested.  # noqa: E501

        :return: The app_filter_regex of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._app_filter_regex

    @app_filter_regex.setter
    def app_filter_regex(self, app_filter_regex):
        """Sets the app_filter_regex of this AppDynamicsConfiguration.

        List of regular expressions that a application name must match (case-insensitively) in order to be ingested.  # noqa: E501

        :param app_filter_regex: The app_filter_regex of this AppDynamicsConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._app_filter_regex = app_filter_regex

    @property
    def controller_name(self):
        """Gets the controller_name of this AppDynamicsConfiguration.  # noqa: E501

        Name of the SaaS controller.  # noqa: E501

        :return: The controller_name of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._controller_name

    @controller_name.setter
    def controller_name(self, controller_name):
        """Sets the controller_name of this AppDynamicsConfiguration.

        Name of the SaaS controller.  # noqa: E501

        :param controller_name: The controller_name of this AppDynamicsConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and controller_name is None:
            raise ValueError("Invalid value for `controller_name`, must not be `None`")  # noqa: E501

        self._controller_name = controller_name

    @property
    def enable_app_infra_metrics(self):
        """Gets the enable_app_infra_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Application Infrastructure metric injection.  # noqa: E501

        :return: The enable_app_infra_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_app_infra_metrics

    @enable_app_infra_metrics.setter
    def enable_app_infra_metrics(self, enable_app_infra_metrics):
        """Sets the enable_app_infra_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Application Infrastructure metric injection.  # noqa: E501

        :param enable_app_infra_metrics: The enable_app_infra_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_app_infra_metrics = enable_app_infra_metrics

    @property
    def enable_backend_metrics(self):
        """Gets the enable_backend_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Backend metric injection.  # noqa: E501

        :return: The enable_backend_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_backend_metrics

    @enable_backend_metrics.setter
    def enable_backend_metrics(self, enable_backend_metrics):
        """Sets the enable_backend_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Backend metric injection.  # noqa: E501

        :param enable_backend_metrics: The enable_backend_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_backend_metrics = enable_backend_metrics

    @property
    def enable_business_trx_metrics(self):
        """Gets the enable_business_trx_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Business Transaction metric injection.  # noqa: E501

        :return: The enable_business_trx_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_business_trx_metrics

    @enable_business_trx_metrics.setter
    def enable_business_trx_metrics(self, enable_business_trx_metrics):
        """Sets the enable_business_trx_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Business Transaction metric injection.  # noqa: E501

        :param enable_business_trx_metrics: The enable_business_trx_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_business_trx_metrics = enable_business_trx_metrics

    @property
    def enable_error_metrics(self):
        """Gets the enable_error_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Error metric injection.  # noqa: E501

        :return: The enable_error_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_error_metrics

    @enable_error_metrics.setter
    def enable_error_metrics(self, enable_error_metrics):
        """Sets the enable_error_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Error metric injection.  # noqa: E501

        :param enable_error_metrics: The enable_error_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_error_metrics = enable_error_metrics

    @property
    def enable_individual_node_metrics(self):
        """Gets the enable_individual_node_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Individual Node metric injection.  # noqa: E501

        :return: The enable_individual_node_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_individual_node_metrics

    @enable_individual_node_metrics.setter
    def enable_individual_node_metrics(self, enable_individual_node_metrics):
        """Sets the enable_individual_node_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Individual Node metric injection.  # noqa: E501

        :param enable_individual_node_metrics: The enable_individual_node_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_individual_node_metrics = enable_individual_node_metrics

    @property
    def enable_overall_perf_metrics(self):
        """Gets the enable_overall_perf_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Overall Performance metric injection.  # noqa: E501

        :return: The enable_overall_perf_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_overall_perf_metrics

    @enable_overall_perf_metrics.setter
    def enable_overall_perf_metrics(self, enable_overall_perf_metrics):
        """Sets the enable_overall_perf_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Overall Performance metric injection.  # noqa: E501

        :param enable_overall_perf_metrics: The enable_overall_perf_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_overall_perf_metrics = enable_overall_perf_metrics

    @property
    def enable_rollup(self):
        """Gets the enable_rollup of this AppDynamicsConfiguration.  # noqa: E501

        Set this to 'false' to get separate results for all values within the time range, by default it is 'true'.  # noqa: E501

        :return: The enable_rollup of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_rollup

    @enable_rollup.setter
    def enable_rollup(self, enable_rollup):
        """Sets the enable_rollup of this AppDynamicsConfiguration.

        Set this to 'false' to get separate results for all values within the time range, by default it is 'true'.  # noqa: E501

        :param enable_rollup: The enable_rollup of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_rollup = enable_rollup

    @property
    def enable_service_endpoint_metrics(self):
        """Gets the enable_service_endpoint_metrics of this AppDynamicsConfiguration.  # noqa: E501

        Boolean flag to control Service End point metric injection.  # noqa: E501

        :return: The enable_service_endpoint_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_service_endpoint_metrics

    @enable_service_endpoint_metrics.setter
    def enable_service_endpoint_metrics(self, enable_service_endpoint_metrics):
        """Sets the enable_service_endpoint_metrics of this AppDynamicsConfiguration.

        Boolean flag to control Service End point metric injection.  # noqa: E501

        :param enable_service_endpoint_metrics: The enable_service_endpoint_metrics of this AppDynamicsConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_service_endpoint_metrics = enable_service_endpoint_metrics

    @property
    def encrypted_password(self):
        """Gets the encrypted_password of this AppDynamicsConfiguration.  # noqa: E501

        Password for AppDynamics user.  # noqa: E501

        :return: The encrypted_password of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._encrypted_password

    @encrypted_password.setter
    def encrypted_password(self, encrypted_password):
        """Sets the encrypted_password of this AppDynamicsConfiguration.

        Password for AppDynamics user.  # noqa: E501

        :param encrypted_password: The encrypted_password of this AppDynamicsConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and encrypted_password is None:
            raise ValueError("Invalid value for `encrypted_password`, must not be `None`")  # noqa: E501

        self._encrypted_password = encrypted_password

    @property
    def user_name(self):
        """Gets the user_name of this AppDynamicsConfiguration.  # noqa: E501

        Username is combination of userName and the account name.  # noqa: E501

        :return: The user_name of this AppDynamicsConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this AppDynamicsConfiguration.

        Username is combination of userName and the account name.  # noqa: E501

        :param user_name: The user_name of this AppDynamicsConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and user_name is None:
            raise ValueError("Invalid value for `user_name`, must not be `None`")  # noqa: E501

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppDynamicsConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppDynamicsConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppDynamicsConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Trace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_ms': 'int',
        'spans': 'list[Span]',
        'start_ms': 'int',
        'total_duration_ms': 'int',
        'trace_id': 'str'
    }

    attribute_map = {
        'end_ms': 'end_ms',
        'spans': 'spans',
        'start_ms': 'start_ms',
        'total_duration_ms': 'total_duration_ms',
        'trace_id': 'traceId'
    }

    def __init__(self, end_ms=None, spans=None, start_ms=None, total_duration_ms=None, trace_id=None, _configuration=None):  # noqa: E501
        """Trace - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._end_ms = None
        self._spans = None
        self._start_ms = None
        self._total_duration_ms = None
        self._trace_id = None
        self.discriminator = None

        if end_ms is not None:
            self.end_ms = end_ms
        if spans is not None:
            self.spans = spans
        if start_ms is not None:
            self.start_ms = start_ms
        if total_duration_ms is not None:
            self.total_duration_ms = total_duration_ms
        if trace_id is not None:
            self.trace_id = trace_id

    @property
    def end_ms(self):
        """Gets the end_ms of this Trace.  # noqa: E501

        Trace end time (in milliseconds)  # noqa: E501

        :return: The end_ms of this Trace.  # noqa: E501
        :rtype: int
        """
        return self._end_ms

    @end_ms.setter
    def end_ms(self, end_ms):
        """Sets the end_ms of this Trace.

        Trace end time (in milliseconds)  # noqa: E501

        :param end_ms: The end_ms of this Trace.  # noqa: E501
        :type: int
        """

        self._end_ms = end_ms

    @property
    def spans(self):
        """Gets the spans of this Trace.  # noqa: E501

        Spans associated with this trace  # noqa: E501

        :return: The spans of this Trace.  # noqa: E501
        :rtype: list[Span]
        """
        return self._spans

    @spans.setter
    def spans(self, spans):
        """Sets the spans of this Trace.

        Spans associated with this trace  # noqa: E501

        :param spans: The spans of this Trace.  # noqa: E501
        :type: list[Span]
        """

        self._spans = spans

    @property
    def start_ms(self):
        """Gets the start_ms of this Trace.  # noqa: E501

        Trace start time (in milliseconds)  # noqa: E501

        :return: The start_ms of this Trace.  # noqa: E501
        :rtype: int
        """
        return self._start_ms

    @start_ms.setter
    def start_ms(self, start_ms):
        """Sets the start_ms of this Trace.

        Trace start time (in milliseconds)  # noqa: E501

        :param start_ms: The start_ms of this Trace.  # noqa: E501
        :type: int
        """

        self._start_ms = start_ms

    @property
    def total_duration_ms(self):
        """Gets the total_duration_ms of this Trace.  # noqa: E501

        Trace total duration (in milliseconds)  # noqa: E501

        :return: The total_duration_ms of this Trace.  # noqa: E501
        :rtype: int
        """
        return self._total_duration_ms

    @total_duration_ms.setter
    def total_duration_ms(self, total_duration_ms):
        """Sets the total_duration_ms of this Trace.

        Trace total duration (in milliseconds)  # noqa: E501

        :param total_duration_ms: The total_duration_ms of this Trace.  # noqa: E501
        :type: int
        """

        self._total_duration_ms = total_duration_ms

    @property
    def trace_id(self):
        """Gets the trace_id of this Trace.  # noqa: E501

        Trace ID  # noqa: E501

        :return: The trace_id of this Trace.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this Trace.

        Trace ID  # noqa: E501

        :param trace_id: The trace_id of this Trace.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Trace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Trace):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Trace):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Proxy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bytes_left_for_buffer': 'int',
        'bytes_per_minute_for_buffer': 'int',
        'collector_rate_limit': 'int',
        'collector_sets_rate_limit': 'bool',
        'customer_id': 'str',
        'deleted': 'bool',
        'ephemeral': 'bool',
        'events_rate_limit': 'float',
        'histogram_rate_limit': 'int',
        'hostname': 'str',
        'id': 'str',
        'in_trash': 'bool',
        'ingestion_policy': 'IngestionPolicy',
        'last_check_in_time': 'int',
        'last_error_event': 'Event',
        'last_error_time': 'int',
        'last_known_error': 'str',
        'local_queue_size': 'int',
        'name': 'str',
        'preprocessor_rules': 'str',
        'shutdown': 'bool',
        'source_tags_rate_limit': 'float',
        'span_logs_rate_limit': 'int',
        'span_rate_limit': 'int',
        'ssh_agent': 'bool',
        'status': 'str',
        'status_cause': 'str',
        'time_drift': 'int',
        'user_id': 'str',
        'version': 'str'
    }

    attribute_map = {
        'bytes_left_for_buffer': 'bytesLeftForBuffer',
        'bytes_per_minute_for_buffer': 'bytesPerMinuteForBuffer',
        'collector_rate_limit': 'collectorRateLimit',
        'collector_sets_rate_limit': 'collectorSetsRateLimit',
        'customer_id': 'customerId',
        'deleted': 'deleted',
        'ephemeral': 'ephemeral',
        'events_rate_limit': 'eventsRateLimit',
        'histogram_rate_limit': 'histogramRateLimit',
        'hostname': 'hostname',
        'id': 'id',
        'in_trash': 'inTrash',
        'ingestion_policy': 'ingestionPolicy',
        'last_check_in_time': 'lastCheckInTime',
        'last_error_event': 'lastErrorEvent',
        'last_error_time': 'lastErrorTime',
        'last_known_error': 'lastKnownError',
        'local_queue_size': 'localQueueSize',
        'name': 'name',
        'preprocessor_rules': 'preprocessorRules',
        'shutdown': 'shutdown',
        'source_tags_rate_limit': 'sourceTagsRateLimit',
        'span_logs_rate_limit': 'spanLogsRateLimit',
        'span_rate_limit': 'spanRateLimit',
        'ssh_agent': 'sshAgent',
        'status': 'status',
        'status_cause': 'statusCause',
        'time_drift': 'timeDrift',
        'user_id': 'userId',
        'version': 'version'
    }

    def __init__(self, bytes_left_for_buffer=None, bytes_per_minute_for_buffer=None, collector_rate_limit=None, collector_sets_rate_limit=None, customer_id=None, deleted=None, ephemeral=None, events_rate_limit=None, histogram_rate_limit=None, hostname=None, id=None, in_trash=None, ingestion_policy=None, last_check_in_time=None, last_error_event=None, last_error_time=None, last_known_error=None, local_queue_size=None, name=None, preprocessor_rules=None, shutdown=None, source_tags_rate_limit=None, span_logs_rate_limit=None, span_rate_limit=None, ssh_agent=None, status=None, status_cause=None, time_drift=None, user_id=None, version=None, _configuration=None):  # noqa: E501
        """Proxy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bytes_left_for_buffer = None
        self._bytes_per_minute_for_buffer = None
        self._collector_rate_limit = None
        self._collector_sets_rate_limit = None
        self._customer_id = None
        self._deleted = None
        self._ephemeral = None
        self._events_rate_limit = None
        self._histogram_rate_limit = None
        self._hostname = None
        self._id = None
        self._in_trash = None
        self._ingestion_policy = None
        self._last_check_in_time = None
        self._last_error_event = None
        self._last_error_time = None
        self._last_known_error = None
        self._local_queue_size = None
        self._name = None
        self._preprocessor_rules = None
        self._shutdown = None
        self._source_tags_rate_limit = None
        self._span_logs_rate_limit = None
        self._span_rate_limit = None
        self._ssh_agent = None
        self._status = None
        self._status_cause = None
        self._time_drift = None
        self._user_id = None
        self._version = None
        self.discriminator = None

        if bytes_left_for_buffer is not None:
            self.bytes_left_for_buffer = bytes_left_for_buffer
        if bytes_per_minute_for_buffer is not None:
            self.bytes_per_minute_for_buffer = bytes_per_minute_for_buffer
        if collector_rate_limit is not None:
            self.collector_rate_limit = collector_rate_limit
        if collector_sets_rate_limit is not None:
            self.collector_sets_rate_limit = collector_sets_rate_limit
        if customer_id is not None:
            self.customer_id = customer_id
        if deleted is not None:
            self.deleted = deleted
        if ephemeral is not None:
            self.ephemeral = ephemeral
        if events_rate_limit is not None:
            self.events_rate_limit = events_rate_limit
        if histogram_rate_limit is not None:
            self.histogram_rate_limit = histogram_rate_limit
        if hostname is not None:
            self.hostname = hostname
        if id is not None:
            self.id = id
        if in_trash is not None:
            self.in_trash = in_trash
        if ingestion_policy is not None:
            self.ingestion_policy = ingestion_policy
        if last_check_in_time is not None:
            self.last_check_in_time = last_check_in_time
        if last_error_event is not None:
            self.last_error_event = last_error_event
        if last_error_time is not None:
            self.last_error_time = last_error_time
        if last_known_error is not None:
            self.last_known_error = last_known_error
        if local_queue_size is not None:
            self.local_queue_size = local_queue_size
        self.name = name
        if preprocessor_rules is not None:
            self.preprocessor_rules = preprocessor_rules
        if shutdown is not None:
            self.shutdown = shutdown
        if source_tags_rate_limit is not None:
            self.source_tags_rate_limit = source_tags_rate_limit
        if span_logs_rate_limit is not None:
            self.span_logs_rate_limit = span_logs_rate_limit
        if span_rate_limit is not None:
            self.span_rate_limit = span_rate_limit
        if ssh_agent is not None:
            self.ssh_agent = ssh_agent
        if status is not None:
            self.status = status
        if status_cause is not None:
            self.status_cause = status_cause
        if time_drift is not None:
            self.time_drift = time_drift
        if user_id is not None:
            self.user_id = user_id
        if version is not None:
            self.version = version

    @property
    def bytes_left_for_buffer(self):
        """Gets the bytes_left_for_buffer of this Proxy.  # noqa: E501

        Number of bytes of space remaining in the persistent disk queue of this proxy  # noqa: E501

        :return: The bytes_left_for_buffer of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._bytes_left_for_buffer

    @bytes_left_for_buffer.setter
    def bytes_left_for_buffer(self, bytes_left_for_buffer):
        """Sets the bytes_left_for_buffer of this Proxy.

        Number of bytes of space remaining in the persistent disk queue of this proxy  # noqa: E501

        :param bytes_left_for_buffer: The bytes_left_for_buffer of this Proxy.  # noqa: E501
        :type: int
        """

        self._bytes_left_for_buffer = bytes_left_for_buffer

    @property
    def bytes_per_minute_for_buffer(self):
        """Gets the bytes_per_minute_for_buffer of this Proxy.  # noqa: E501

        Bytes used per minute by the persistent disk queue of this proxy  # noqa: E501

        :return: The bytes_per_minute_for_buffer of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._bytes_per_minute_for_buffer

    @bytes_per_minute_for_buffer.setter
    def bytes_per_minute_for_buffer(self, bytes_per_minute_for_buffer):
        """Sets the bytes_per_minute_for_buffer of this Proxy.

        Bytes used per minute by the persistent disk queue of this proxy  # noqa: E501

        :param bytes_per_minute_for_buffer: The bytes_per_minute_for_buffer of this Proxy.  # noqa: E501
        :type: int
        """

        self._bytes_per_minute_for_buffer = bytes_per_minute_for_buffer

    @property
    def collector_rate_limit(self):
        """Gets the collector_rate_limit of this Proxy.  # noqa: E501

        Proxy's rate limit  # noqa: E501

        :return: The collector_rate_limit of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._collector_rate_limit

    @collector_rate_limit.setter
    def collector_rate_limit(self, collector_rate_limit):
        """Sets the collector_rate_limit of this Proxy.

        Proxy's rate limit  # noqa: E501

        :param collector_rate_limit: The collector_rate_limit of this Proxy.  # noqa: E501
        :type: int
        """

        self._collector_rate_limit = collector_rate_limit

    @property
    def collector_sets_rate_limit(self):
        """Gets the collector_sets_rate_limit of this Proxy.  # noqa: E501

        When true, this proxy's rate limit is controlled remotely  # noqa: E501

        :return: The collector_sets_rate_limit of this Proxy.  # noqa: E501
        :rtype: bool
        """
        return self._collector_sets_rate_limit

    @collector_sets_rate_limit.setter
    def collector_sets_rate_limit(self, collector_sets_rate_limit):
        """Sets the collector_sets_rate_limit of this Proxy.

        When true, this proxy's rate limit is controlled remotely  # noqa: E501

        :param collector_sets_rate_limit: The collector_sets_rate_limit of this Proxy.  # noqa: E501
        :type: bool
        """

        self._collector_sets_rate_limit = collector_sets_rate_limit

    @property
    def customer_id(self):
        """Gets the customer_id of this Proxy.  # noqa: E501


        :return: The customer_id of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this Proxy.


        :param customer_id: The customer_id of this Proxy.  # noqa: E501
        :type: str
        """

        self._customer_id = customer_id

    @property
    def deleted(self):
        """Gets the deleted of this Proxy.  # noqa: E501


        :return: The deleted of this Proxy.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this Proxy.


        :param deleted: The deleted of this Proxy.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def ephemeral(self):
        """Gets the ephemeral of this Proxy.  # noqa: E501

        When true, this proxy is expected to be ephemeral (possibly hosted on a short-lived container) and will be deleted after a period of inactivity (not checking in)  # noqa: E501

        :return: The ephemeral of this Proxy.  # noqa: E501
        :rtype: bool
        """
        return self._ephemeral

    @ephemeral.setter
    def ephemeral(self, ephemeral):
        """Sets the ephemeral of this Proxy.

        When true, this proxy is expected to be ephemeral (possibly hosted on a short-lived container) and will be deleted after a period of inactivity (not checking in)  # noqa: E501

        :param ephemeral: The ephemeral of this Proxy.  # noqa: E501
        :type: bool
        """

        self._ephemeral = ephemeral

    @property
    def events_rate_limit(self):
        """Gets the events_rate_limit of this Proxy.  # noqa: E501

        Proxy's rate limit for events  # noqa: E501

        :return: The events_rate_limit of this Proxy.  # noqa: E501
        :rtype: float
        """
        return self._events_rate_limit

    @events_rate_limit.setter
    def events_rate_limit(self, events_rate_limit):
        """Sets the events_rate_limit of this Proxy.

        Proxy's rate limit for events  # noqa: E501

        :param events_rate_limit: The events_rate_limit of this Proxy.  # noqa: E501
        :type: float
        """

        self._events_rate_limit = events_rate_limit

    @property
    def histogram_rate_limit(self):
        """Gets the histogram_rate_limit of this Proxy.  # noqa: E501

        Proxy's rate limit for histograms  # noqa: E501

        :return: The histogram_rate_limit of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._histogram_rate_limit

    @histogram_rate_limit.setter
    def histogram_rate_limit(self, histogram_rate_limit):
        """Sets the histogram_rate_limit of this Proxy.

        Proxy's rate limit for histograms  # noqa: E501

        :param histogram_rate_limit: The histogram_rate_limit of this Proxy.  # noqa: E501
        :type: int
        """

        self._histogram_rate_limit = histogram_rate_limit

    @property
    def hostname(self):
        """Gets the hostname of this Proxy.  # noqa: E501

        Host name of the machine running the proxy  # noqa: E501

        :return: The hostname of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this Proxy.

        Host name of the machine running the proxy  # noqa: E501

        :param hostname: The hostname of this Proxy.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def id(self):
        """Gets the id of this Proxy.  # noqa: E501


        :return: The id of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Proxy.


        :param id: The id of this Proxy.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def in_trash(self):
        """Gets the in_trash of this Proxy.  # noqa: E501


        :return: The in_trash of this Proxy.  # noqa: E501
        :rtype: bool
        """
        return self._in_trash

    @in_trash.setter
    def in_trash(self, in_trash):
        """Sets the in_trash of this Proxy.


        :param in_trash: The in_trash of this Proxy.  # noqa: E501
        :type: bool
        """

        self._in_trash = in_trash

    @property
    def ingestion_policy(self):
        """Gets the ingestion_policy of this Proxy.  # noqa: E501

        Ingestion policy associated with the proxy  # noqa: E501

        :return: The ingestion_policy of this Proxy.  # noqa: E501
        :rtype: IngestionPolicy
        """
        return self._ingestion_policy

    @ingestion_policy.setter
    def ingestion_policy(self, ingestion_policy):
        """Sets the ingestion_policy of this Proxy.

        Ingestion policy associated with the proxy  # noqa: E501

        :param ingestion_policy: The ingestion_policy of this Proxy.  # noqa: E501
        :type: IngestionPolicy
        """

        self._ingestion_policy = ingestion_policy

    @property
    def last_check_in_time(self):
        """Gets the last_check_in_time of this Proxy.  # noqa: E501

        Last time when this proxy checked in (in milliseconds since the unix epoch)  # noqa: E501

        :return: The last_check_in_time of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._last_check_in_time

    @last_check_in_time.setter
    def last_check_in_time(self, last_check_in_time):
        """Sets the last_check_in_time of this Proxy.

        Last time when this proxy checked in (in milliseconds since the unix epoch)  # noqa: E501

        :param last_check_in_time: The last_check_in_time of this Proxy.  # noqa: E501
        :type: int
        """

        self._last_check_in_time = last_check_in_time

    @property
    def last_error_event(self):
        """Gets the last_error_event of this Proxy.  # noqa: E501


        :return: The last_error_event of this Proxy.  # noqa: E501
        :rtype: Event
        """
        return self._last_error_event

    @last_error_event.setter
    def last_error_event(self, last_error_event):
        """Sets the last_error_event of this Proxy.


        :param last_error_event: The last_error_event of this Proxy.  # noqa: E501
        :type: Event
        """

        self._last_error_event = last_error_event

    @property
    def last_error_time(self):
        """Gets the last_error_time of this Proxy.  # noqa: E501

        deprecated  # noqa: E501

        :return: The last_error_time of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._last_error_time

    @last_error_time.setter
    def last_error_time(self, last_error_time):
        """Sets the last_error_time of this Proxy.

        deprecated  # noqa: E501

        :param last_error_time: The last_error_time of this Proxy.  # noqa: E501
        :type: int
        """

        self._last_error_time = last_error_time

    @property
    def last_known_error(self):
        """Gets the last_known_error of this Proxy.  # noqa: E501

        deprecated  # noqa: E501

        :return: The last_known_error of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._last_known_error

    @last_known_error.setter
    def last_known_error(self, last_known_error):
        """Sets the last_known_error of this Proxy.

        deprecated  # noqa: E501

        :param last_known_error: The last_known_error of this Proxy.  # noqa: E501
        :type: str
        """

        self._last_known_error = last_known_error

    @property
    def local_queue_size(self):
        """Gets the local_queue_size of this Proxy.  # noqa: E501

        Number of items in the persistent disk queue of this proxy  # noqa: E501

        :return: The local_queue_size of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._local_queue_size

    @local_queue_size.setter
    def local_queue_size(self, local_queue_size):
        """Sets the local_queue_size of this Proxy.

        Number of items in the persistent disk queue of this proxy  # noqa: E501

        :param local_queue_size: The local_queue_size of this Proxy.  # noqa: E501
        :type: int
        """

        self._local_queue_size = local_queue_size

    @property
    def name(self):
        """Gets the name of this Proxy.  # noqa: E501

        Proxy name (modifiable)  # noqa: E501

        :return: The name of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Proxy.

        Proxy name (modifiable)  # noqa: E501

        :param name: The name of this Proxy.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def preprocessor_rules(self):
        """Gets the preprocessor_rules of this Proxy.  # noqa: E501

        Proxy's preprocessor rules  # noqa: E501

        :return: The preprocessor_rules of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._preprocessor_rules

    @preprocessor_rules.setter
    def preprocessor_rules(self, preprocessor_rules):
        """Sets the preprocessor_rules of this Proxy.

        Proxy's preprocessor rules  # noqa: E501

        :param preprocessor_rules: The preprocessor_rules of this Proxy.  # noqa: E501
        :type: str
        """

        self._preprocessor_rules = preprocessor_rules

    @property
    def shutdown(self):
        """Gets the shutdown of this Proxy.  # noqa: E501

        When true, attempt to shut down this proxy remotely  # noqa: E501

        :return: The shutdown of this Proxy.  # noqa: E501
        :rtype: bool
        """
        return self._shutdown

    @shutdown.setter
    def shutdown(self, shutdown):
        """Sets the shutdown of this Proxy.

        When true, attempt to shut down this proxy remotely  # noqa: E501

        :param shutdown: The shutdown of this Proxy.  # noqa: E501
        :type: bool
        """

        self._shutdown = shutdown

    @property
    def source_tags_rate_limit(self):
        """Gets the source_tags_rate_limit of this Proxy.  # noqa: E501

        Proxy's rate limit for source tag operations  # noqa: E501

        :return: The source_tags_rate_limit of this Proxy.  # noqa: E501
        :rtype: float
        """
        return self._source_tags_rate_limit

    @source_tags_rate_limit.setter
    def source_tags_rate_limit(self, source_tags_rate_limit):
        """Sets the source_tags_rate_limit of this Proxy.

        Proxy's rate limit for source tag operations  # noqa: E501

        :param source_tags_rate_limit: The source_tags_rate_limit of this Proxy.  # noqa: E501
        :type: float
        """

        self._source_tags_rate_limit = source_tags_rate_limit

    @property
    def span_logs_rate_limit(self):
        """Gets the span_logs_rate_limit of this Proxy.  # noqa: E501

        Proxy's rate limit for span logs  # noqa: E501

        :return: The span_logs_rate_limit of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._span_logs_rate_limit

    @span_logs_rate_limit.setter
    def span_logs_rate_limit(self, span_logs_rate_limit):
        """Sets the span_logs_rate_limit of this Proxy.

        Proxy's rate limit for span logs  # noqa: E501

        :param span_logs_rate_limit: The span_logs_rate_limit of this Proxy.  # noqa: E501
        :type: int
        """

        self._span_logs_rate_limit = span_logs_rate_limit

    @property
    def span_rate_limit(self):
        """Gets the span_rate_limit of this Proxy.  # noqa: E501

        Proxy's rate limit for spans  # noqa: E501

        :return: The span_rate_limit of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._span_rate_limit

    @span_rate_limit.setter
    def span_rate_limit(self, span_rate_limit):
        """Sets the span_rate_limit of this Proxy.

        Proxy's rate limit for spans  # noqa: E501

        :param span_rate_limit: The span_rate_limit of this Proxy.  # noqa: E501
        :type: int
        """

        self._span_rate_limit = span_rate_limit

    @property
    def ssh_agent(self):
        """Gets the ssh_agent of this Proxy.  # noqa: E501

        deprecated  # noqa: E501

        :return: The ssh_agent of this Proxy.  # noqa: E501
        :rtype: bool
        """
        return self._ssh_agent

    @ssh_agent.setter
    def ssh_agent(self, ssh_agent):
        """Sets the ssh_agent of this Proxy.

        deprecated  # noqa: E501

        :param ssh_agent: The ssh_agent of this Proxy.  # noqa: E501
        :type: bool
        """

        self._ssh_agent = ssh_agent

    @property
    def status(self):
        """Gets the status of this Proxy.  # noqa: E501

        the proxy's status  # noqa: E501

        :return: The status of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Proxy.

        the proxy's status  # noqa: E501

        :param status: The status of this Proxy.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "STOPPED_UNKNOWN", "STOPPED_BY_SERVER"]  # noqa: E501
        if (self._configuration.client_side_validation and
                status not in allowed_values):
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def status_cause(self):
        """Gets the status_cause of this Proxy.  # noqa: E501

        The reason why the proxy is in current status  # noqa: E501

        :return: The status_cause of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._status_cause

    @status_cause.setter
    def status_cause(self, status_cause):
        """Sets the status_cause of this Proxy.

        The reason why the proxy is in current status  # noqa: E501

        :param status_cause: The status_cause of this Proxy.  # noqa: E501
        :type: str
        """

        self._status_cause = status_cause

    @property
    def time_drift(self):
        """Gets the time_drift of this Proxy.  # noqa: E501

        Time drift of the proxy's clock compared to Wavefront servers  # noqa: E501

        :return: The time_drift of this Proxy.  # noqa: E501
        :rtype: int
        """
        return self._time_drift

    @time_drift.setter
    def time_drift(self, time_drift):
        """Sets the time_drift of this Proxy.

        Time drift of the proxy's clock compared to Wavefront servers  # noqa: E501

        :param time_drift: The time_drift of this Proxy.  # noqa: E501
        :type: int
        """

        self._time_drift = time_drift

    @property
    def user_id(self):
        """Gets the user_id of this Proxy.  # noqa: E501

        The user associated with this proxy  # noqa: E501

        :return: The user_id of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Proxy.

        The user associated with this proxy  # noqa: E501

        :param user_id: The user_id of this Proxy.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def version(self):
        """Gets the version of this Proxy.  # noqa: E501


        :return: The version of this Proxy.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Proxy.


        :param version: The version of this Proxy.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Proxy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Proxy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Proxy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class DerivedMetricDefinition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_information': 'str',
        'create_user_id': 'str',
        'created': 'int',
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'deleted': 'bool',
        'hosts_used': 'list[str]',
        'id': 'str',
        'in_trash': 'bool',
        'include_obsolete_metrics': 'bool',
        'last_error_message': 'str',
        'last_failed_time': 'int',
        'last_processed_millis': 'int',
        'last_query_time': 'int',
        'metrics_used': 'list[str]',
        'minutes': 'int',
        'name': 'str',
        'points_scanned_at_last_query': 'int',
        'process_rate_minutes': 'int',
        'query': 'str',
        'query_failing': 'bool',
        'query_qb_enabled': 'bool',
        'query_qb_serialization': 'str',
        'status': 'list[str]',
        'tags': 'WFTags',
        'update_user_id': 'str',
        'updated': 'int',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'additional_information': 'additionalInformation',
        'create_user_id': 'createUserId',
        'created': 'created',
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'deleted': 'deleted',
        'hosts_used': 'hostsUsed',
        'id': 'id',
        'in_trash': 'inTrash',
        'include_obsolete_metrics': 'includeObsoleteMetrics',
        'last_error_message': 'lastErrorMessage',
        'last_failed_time': 'lastFailedTime',
        'last_processed_millis': 'lastProcessedMillis',
        'last_query_time': 'lastQueryTime',
        'metrics_used': 'metricsUsed',
        'minutes': 'minutes',
        'name': 'name',
        'points_scanned_at_last_query': 'pointsScannedAtLastQuery',
        'process_rate_minutes': 'processRateMinutes',
        'query': 'query',
        'query_failing': 'queryFailing',
        'query_qb_enabled': 'queryQBEnabled',
        'query_qb_serialization': 'queryQBSerialization',
        'status': 'status',
        'tags': 'tags',
        'update_user_id': 'updateUserId',
        'updated': 'updated',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, additional_information=None, create_user_id=None, created=None, created_epoch_millis=None, creator_id=None, deleted=None, hosts_used=None, id=None, in_trash=None, include_obsolete_metrics=None, last_error_message=None, last_failed_time=None, last_processed_millis=None, last_query_time=None, metrics_used=None, minutes=None, name=None, points_scanned_at_last_query=None, process_rate_minutes=None, query=None, query_failing=None, query_qb_enabled=None, query_qb_serialization=None, status=None, tags=None, update_user_id=None, updated=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """DerivedMetricDefinition - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._additional_information = None
        self._create_user_id = None
        self._created = None
        self._created_epoch_millis = None
        self._creator_id = None
        self._deleted = None
        self._hosts_used = None
        self._id = None
        self._in_trash = None
        self._include_obsolete_metrics = None
        self._last_error_message = None
        self._last_failed_time = None
        self._last_processed_millis = None
        self._last_query_time = None
        self._metrics_used = None
        self._minutes = None
        self._name = None
        self._points_scanned_at_last_query = None
        self._process_rate_minutes = None
        self._query = None
        self._query_failing = None
        self._query_qb_enabled = None
        self._query_qb_serialization = None
        self._status = None
        self._tags = None
        self._update_user_id = None
        self._updated = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if additional_information is not None:
            self.additional_information = additional_information
        if create_user_id is not None:
            self.create_user_id = create_user_id
        if created is not None:
            self.created = created
        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if deleted is not None:
            self.deleted = deleted
        if hosts_used is not None:
            self.hosts_used = hosts_used
        if id is not None:
            self.id = id
        if in_trash is not None:
            self.in_trash = in_trash
        if include_obsolete_metrics is not None:
            self.include_obsolete_metrics = include_obsolete_metrics
        if last_error_message is not None:
            self.last_error_message = last_error_message
        if last_failed_time is not None:
            self.last_failed_time = last_failed_time
        if last_processed_millis is not None:
            self.last_processed_millis = last_processed_millis
        if last_query_time is not None:
            self.last_query_time = last_query_time
        if metrics_used is not None:
            self.metrics_used = metrics_used
        self.minutes = minutes
        self.name = name
        if points_scanned_at_last_query is not None:
            self.points_scanned_at_last_query = points_scanned_at_last_query
        if process_rate_minutes is not None:
            self.process_rate_minutes = process_rate_minutes
        self.query = query
        if query_failing is not None:
            self.query_failing = query_failing
        if query_qb_enabled is not None:
            self.query_qb_enabled = query_qb_enabled
        if query_qb_serialization is not None:
            self.query_qb_serialization = query_qb_serialization
        if status is not None:
            self.status = status
        if tags is not None:
            self.tags = tags
        if update_user_id is not None:
            self.update_user_id = update_user_id
        if updated is not None:
            self.updated = updated
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def additional_information(self):
        """Gets the additional_information of this DerivedMetricDefinition.  # noqa: E501

        User-supplied additional explanatory information for the derived metric  # noqa: E501

        :return: The additional_information of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._additional_information

    @additional_information.setter
    def additional_information(self, additional_information):
        """Sets the additional_information of this DerivedMetricDefinition.

        User-supplied additional explanatory information for the derived metric  # noqa: E501

        :param additional_information: The additional_information of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._additional_information = additional_information

    @property
    def create_user_id(self):
        """Gets the create_user_id of this DerivedMetricDefinition.  # noqa: E501


        :return: The create_user_id of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._create_user_id

    @create_user_id.setter
    def create_user_id(self, create_user_id):
        """Sets the create_user_id of this DerivedMetricDefinition.


        :param create_user_id: The create_user_id of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._create_user_id = create_user_id

    @property
    def created(self):
        """Gets the created of this DerivedMetricDefinition.  # noqa: E501

        When this derived metric was created, in epoch millis  # noqa: E501

        :return: The created of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DerivedMetricDefinition.

        When this derived metric was created, in epoch millis  # noqa: E501

        :param created: The created of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this DerivedMetricDefinition.  # noqa: E501


        :return: The created_epoch_millis of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this DerivedMetricDefinition.


        :param created_epoch_millis: The created_epoch_millis of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this DerivedMetricDefinition.  # noqa: E501


        :return: The creator_id of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this DerivedMetricDefinition.


        :param creator_id: The creator_id of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def deleted(self):
        """Gets the deleted of this DerivedMetricDefinition.  # noqa: E501


        :return: The deleted of this DerivedMetricDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this DerivedMetricDefinition.


        :param deleted: The deleted of this DerivedMetricDefinition.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def hosts_used(self):
        """Gets the hosts_used of this DerivedMetricDefinition.  # noqa: E501

        Number of hosts checked by the query  # noqa: E501

        :return: The hosts_used of this DerivedMetricDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._hosts_used

    @hosts_used.setter
    def hosts_used(self, hosts_used):
        """Sets the hosts_used of this DerivedMetricDefinition.

        Number of hosts checked by the query  # noqa: E501

        :param hosts_used: The hosts_used of this DerivedMetricDefinition.  # noqa: E501
        :type: list[str]
        """

        self._hosts_used = hosts_used

    @property
    def id(self):
        """Gets the id of this DerivedMetricDefinition.  # noqa: E501


        :return: The id of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DerivedMetricDefinition.


        :param id: The id of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def in_trash(self):
        """Gets the in_trash of this DerivedMetricDefinition.  # noqa: E501


        :return: The in_trash of this DerivedMetricDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._in_trash

    @in_trash.setter
    def in_trash(self, in_trash):
        """Sets the in_trash of this DerivedMetricDefinition.


        :param in_trash: The in_trash of this DerivedMetricDefinition.  # noqa: E501
        :type: bool
        """

        self._in_trash = in_trash

    @property
    def include_obsolete_metrics(self):
        """Gets the include_obsolete_metrics of this DerivedMetricDefinition.  # noqa: E501

        Whether to include obsolete metrics in query  # noqa: E501

        :return: The include_obsolete_metrics of this DerivedMetricDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._include_obsolete_metrics

    @include_obsolete_metrics.setter
    def include_obsolete_metrics(self, include_obsolete_metrics):
        """Sets the include_obsolete_metrics of this DerivedMetricDefinition.

        Whether to include obsolete metrics in query  # noqa: E501

        :param include_obsolete_metrics: The include_obsolete_metrics of this DerivedMetricDefinition.  # noqa: E501
        :type: bool
        """

        self._include_obsolete_metrics = include_obsolete_metrics

    @property
    def last_error_message(self):
        """Gets the last_error_message of this DerivedMetricDefinition.  # noqa: E501

        The last error encountered when running the query  # noqa: E501

        :return: The last_error_message of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._last_error_message

    @last_error_message.setter
    def last_error_message(self, last_error_message):
        """Sets the last_error_message of this DerivedMetricDefinition.

        The last error encountered when running the query  # noqa: E501

        :param last_error_message: The last_error_message of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._last_error_message = last_error_message

    @property
    def last_failed_time(self):
        """Gets the last_failed_time of this DerivedMetricDefinition.  # noqa: E501

        The time of the last error encountered when running the query, in epoch millis  # noqa: E501

        :return: The last_failed_time of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._last_failed_time

    @last_failed_time.setter
    def last_failed_time(self, last_failed_time):
        """Sets the last_failed_time of this DerivedMetricDefinition.

        The time of the last error encountered when running the query, in epoch millis  # noqa: E501

        :param last_failed_time: The last_failed_time of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._last_failed_time = last_failed_time

    @property
    def last_processed_millis(self):
        """Gets the last_processed_millis of this DerivedMetricDefinition.  # noqa: E501

        The last time when the derived metric query was run, in epoch millis  # noqa: E501

        :return: The last_processed_millis of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._last_processed_millis

    @last_processed_millis.setter
    def last_processed_millis(self, last_processed_millis):
        """Sets the last_processed_millis of this DerivedMetricDefinition.

        The last time when the derived metric query was run, in epoch millis  # noqa: E501

        :param last_processed_millis: The last_processed_millis of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._last_processed_millis = last_processed_millis

    @property
    def last_query_time(self):
        """Gets the last_query_time of this DerivedMetricDefinition.  # noqa: E501

        Time for the query execute, averaged on hourly basis  # noqa: E501

        :return: The last_query_time of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._last_query_time

    @last_query_time.setter
    def last_query_time(self, last_query_time):
        """Sets the last_query_time of this DerivedMetricDefinition.

        Time for the query execute, averaged on hourly basis  # noqa: E501

        :param last_query_time: The last_query_time of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._last_query_time = last_query_time

    @property
    def metrics_used(self):
        """Gets the metrics_used of this DerivedMetricDefinition.  # noqa: E501

        Number of metrics checked by the query  # noqa: E501

        :return: The metrics_used of this DerivedMetricDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._metrics_used

    @metrics_used.setter
    def metrics_used(self, metrics_used):
        """Sets the metrics_used of this DerivedMetricDefinition.

        Number of metrics checked by the query  # noqa: E501

        :param metrics_used: The metrics_used of this DerivedMetricDefinition.  # noqa: E501
        :type: list[str]
        """

        self._metrics_used = metrics_used

    @property
    def minutes(self):
        """Gets the minutes of this DerivedMetricDefinition.  # noqa: E501

        Number of minutes to query for the derived metric  # noqa: E501

        :return: The minutes of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._minutes

    @minutes.setter
    def minutes(self, minutes):
        """Sets the minutes of this DerivedMetricDefinition.

        Number of minutes to query for the derived metric  # noqa: E501

        :param minutes: The minutes of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and minutes is None:
            raise ValueError("Invalid value for `minutes`, must not be `None`")  # noqa: E501

        self._minutes = minutes

    @property
    def name(self):
        """Gets the name of this DerivedMetricDefinition.  # noqa: E501


        :return: The name of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DerivedMetricDefinition.


        :param name: The name of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def points_scanned_at_last_query(self):
        """Gets the points_scanned_at_last_query of this DerivedMetricDefinition.  # noqa: E501

        A derived field recording the number of data points scanned when the system last computed the query  # noqa: E501

        :return: The points_scanned_at_last_query of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._points_scanned_at_last_query

    @points_scanned_at_last_query.setter
    def points_scanned_at_last_query(self, points_scanned_at_last_query):
        """Sets the points_scanned_at_last_query of this DerivedMetricDefinition.

        A derived field recording the number of data points scanned when the system last computed the query  # noqa: E501

        :param points_scanned_at_last_query: The points_scanned_at_last_query of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._points_scanned_at_last_query = points_scanned_at_last_query

    @property
    def process_rate_minutes(self):
        """Gets the process_rate_minutes of this DerivedMetricDefinition.  # noqa: E501

        The interval between executing the query, in minutes.  Defaults to 1 minute  # noqa: E501

        :return: The process_rate_minutes of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._process_rate_minutes

    @process_rate_minutes.setter
    def process_rate_minutes(self, process_rate_minutes):
        """Sets the process_rate_minutes of this DerivedMetricDefinition.

        The interval between executing the query, in minutes.  Defaults to 1 minute  # noqa: E501

        :param process_rate_minutes: The process_rate_minutes of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._process_rate_minutes = process_rate_minutes

    @property
    def query(self):
        """Gets the query of this DerivedMetricDefinition.  # noqa: E501

        A Wavefront query that is evaluated at regular intervals (default 1m).  # noqa: E501

        :return: The query of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this DerivedMetricDefinition.

        A Wavefront query that is evaluated at regular intervals (default 1m).  # noqa: E501

        :param query: The query of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and query is None:
            raise ValueError("Invalid value for `query`, must not be `None`")  # noqa: E501

        self._query = query

    @property
    def query_failing(self):
        """Gets the query_failing of this DerivedMetricDefinition.  # noqa: E501

        Whether there was an exception when the query last ran  # noqa: E501

        :return: The query_failing of this DerivedMetricDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._query_failing

    @query_failing.setter
    def query_failing(self, query_failing):
        """Sets the query_failing of this DerivedMetricDefinition.

        Whether there was an exception when the query last ran  # noqa: E501

        :param query_failing: The query_failing of this DerivedMetricDefinition.  # noqa: E501
        :type: bool
        """

        self._query_failing = query_failing

    @property
    def query_qb_enabled(self):
        """Gets the query_qb_enabled of this DerivedMetricDefinition.  # noqa: E501

        Whether the query was created using the Query Builder. Default false  # noqa: E501

        :return: The query_qb_enabled of this DerivedMetricDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._query_qb_enabled

    @query_qb_enabled.setter
    def query_qb_enabled(self, query_qb_enabled):
        """Sets the query_qb_enabled of this DerivedMetricDefinition.

        Whether the query was created using the Query Builder. Default false  # noqa: E501

        :param query_qb_enabled: The query_qb_enabled of this DerivedMetricDefinition.  # noqa: E501
        :type: bool
        """

        self._query_qb_enabled = query_qb_enabled

    @property
    def query_qb_serialization(self):
        """Gets the query_qb_serialization of this DerivedMetricDefinition.  # noqa: E501

        The special serialization of the Query Builder that corresponds to the query.  Applicable only when queryQBEnabled is true  # noqa: E501

        :return: The query_qb_serialization of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._query_qb_serialization

    @query_qb_serialization.setter
    def query_qb_serialization(self, query_qb_serialization):
        """Sets the query_qb_serialization of this DerivedMetricDefinition.

        The special serialization of the Query Builder that corresponds to the query.  Applicable only when queryQBEnabled is true  # noqa: E501

        :param query_qb_serialization: The query_qb_serialization of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._query_qb_serialization = query_qb_serialization

    @property
    def status(self):
        """Gets the status of this DerivedMetricDefinition.  # noqa: E501

        Lists the current state of the derived metric. Can be one or more of: INVALID, ACTIVE, TRASH, NO_DATA  # noqa: E501

        :return: The status of this DerivedMetricDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DerivedMetricDefinition.

        Lists the current state of the derived metric. Can be one or more of: INVALID, ACTIVE, TRASH, NO_DATA  # noqa: E501

        :param status: The status of this DerivedMetricDefinition.  # noqa: E501
        :type: list[str]
        """

        self._status = status

    @property
    def tags(self):
        """Gets the tags of this DerivedMetricDefinition.  # noqa: E501


        :return: The tags of this DerivedMetricDefinition.  # noqa: E501
        :rtype: WFTags
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this DerivedMetricDefinition.


        :param tags: The tags of this DerivedMetricDefinition.  # noqa: E501
        :type: WFTags
        """

        self._tags = tags

    @property
    def update_user_id(self):
        """Gets the update_user_id of this DerivedMetricDefinition.  # noqa: E501

        The user that last updated this derived metric definition  # noqa: E501

        :return: The update_user_id of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._update_user_id

    @update_user_id.setter
    def update_user_id(self, update_user_id):
        """Sets the update_user_id of this DerivedMetricDefinition.

        The user that last updated this derived metric definition  # noqa: E501

        :param update_user_id: The update_user_id of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._update_user_id = update_user_id

    @property
    def updated(self):
        """Gets the updated of this DerivedMetricDefinition.  # noqa: E501

        When the derived metric definition was last updated, in epoch millis  # noqa: E501

        :return: The updated of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this DerivedMetricDefinition.

        When the derived metric definition was last updated, in epoch millis  # noqa: E501

        :param updated: The updated of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._updated = updated

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this DerivedMetricDefinition.  # noqa: E501


        :return: The updated_epoch_millis of this DerivedMetricDefinition.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this DerivedMetricDefinition.


        :param updated_epoch_millis: The updated_epoch_millis of this DerivedMetricDefinition.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this DerivedMetricDefinition.  # noqa: E501


        :return: The updater_id of this DerivedMetricDefinition.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this DerivedMetricDefinition.


        :param updater_id: The updater_id of this DerivedMetricDefinition.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DerivedMetricDefinition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DerivedMetricDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DerivedMetricDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class GCPBillingConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gcp_api_key': 'str',
        'gcp_json_key': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'gcp_api_key': 'gcpApiKey',
        'gcp_json_key': 'gcpJsonKey',
        'project_id': 'projectId'
    }

    def __init__(self, gcp_api_key=None, gcp_json_key=None, project_id=None, _configuration=None):  # noqa: E501
        """GCPBillingConfiguration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._gcp_api_key = None
        self._gcp_json_key = None
        self._project_id = None
        self.discriminator = None

        self.gcp_api_key = gcp_api_key
        self.gcp_json_key = gcp_json_key
        self.project_id = project_id

    @property
    def gcp_api_key(self):
        """Gets the gcp_api_key of this GCPBillingConfiguration.  # noqa: E501

        API key for Google Cloud Platform (GCP). Use 'saved_api_key' to retain existing API key when updating  # noqa: E501

        :return: The gcp_api_key of this GCPBillingConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._gcp_api_key

    @gcp_api_key.setter
    def gcp_api_key(self, gcp_api_key):
        """Sets the gcp_api_key of this GCPBillingConfiguration.

        API key for Google Cloud Platform (GCP). Use 'saved_api_key' to retain existing API key when updating  # noqa: E501

        :param gcp_api_key: The gcp_api_key of this GCPBillingConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and gcp_api_key is None:
            raise ValueError("Invalid value for `gcp_api_key`, must not be `None`")  # noqa: E501

        self._gcp_api_key = gcp_api_key

    @property
    def gcp_json_key(self):
        """Gets the gcp_json_key of this GCPBillingConfiguration.  # noqa: E501

        Private key for a Google Cloud Platform (GCP) service account within your project.  The account must at least be granted Monitoring Viewer permissions.  This key must be in the JSON format generated by GCP. Use '{\"project_id\": \"%s\"}' to retain the existing key when updating.  # noqa: E501

        :return: The gcp_json_key of this GCPBillingConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._gcp_json_key

    @gcp_json_key.setter
    def gcp_json_key(self, gcp_json_key):
        """Sets the gcp_json_key of this GCPBillingConfiguration.

        Private key for a Google Cloud Platform (GCP) service account within your project.  The account must at least be granted Monitoring Viewer permissions.  This key must be in the JSON format generated by GCP. Use '{\"project_id\": \"%s\"}' to retain the existing key when updating.  # noqa: E501

        :param gcp_json_key: The gcp_json_key of this GCPBillingConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and gcp_json_key is None:
            raise ValueError("Invalid value for `gcp_json_key`, must not be `None`")  # noqa: E501

        self._gcp_json_key = gcp_json_key

    @property
    def project_id(self):
        """Gets the project_id of this GCPBillingConfiguration.  # noqa: E501

        The Google Cloud Platform (GCP) project id.  # noqa: E501

        :return: The project_id of this GCPBillingConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GCPBillingConfiguration.

        The Google Cloud Platform (GCP) project id.  # noqa: E501

        :param project_id: The project_id of this GCPBillingConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GCPBillingConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GCPBillingConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GCPBillingConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class QueryApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def query_api(self, q, s, g, **kwargs):  # noqa: E501
        """Perform a charting query against Wavefront servers that returns the appropriate points in the specified time window and granularity  # noqa: E501

        Long time spans and small granularities can take a long time to calculate  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_api(q, s, g, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str q: the query expression to execute (required)
        :param str s: the start time of the query window in epoch milliseconds (required)
        :param str g: the granularity of the points returned (required)
        :param str n: name used to identify the query
        :param str query_type: the query type of the query
        :param str e: the end time of the query window in epoch milliseconds (null to use now)
        :param str p: the approximate maximum number of points to return (may not limit number of points exactly)
        :param bool i: whether series with only points that are outside of the query window will be returned (defaults to true)
        :param bool auto_events: whether events for sources included in the query will be automatically returned by the query
        :param str summarization: summarization strategy to use when bucketing points together
        :param bool list_mode: retrieve events more optimally displayed for a list
        :param bool strict: do not return points outside the query window [s;e), defaults to false
        :param str view: view of the query result, metric or histogram, defaults to metric
        :param bool include_obsolete_metrics: include metrics that have not been reporting recently, defaults to false
        :param bool sorted: sorts the output so that returned series are in order, defaults to false
        :param bool cached: whether the query cache is used, defaults to true
        :param list[str] dimension_tuples:
        :param bool use_raw_qk:
        :return: QueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_api_with_http_info(q, s, g, **kwargs)  # noqa: E501
        else:
            (data) = self.query_api_with_http_info(q, s, g, **kwargs)  # noqa: E501
            return data

    def query_api_with_http_info(self, q, s, g, **kwargs):  # noqa: E501
        """Perform a charting query against Wavefront servers that returns the appropriate points in the specified time window and granularity  # noqa: E501

        Long time spans and small granularities can take a long time to calculate  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_api_with_http_info(q, s, g, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str q: the query expression to execute (required)
        :param str s: the start time of the query window in epoch milliseconds (required)
        :param str g: the granularity of the points returned (required)
        :param str n: name used to identify the query
        :param str query_type: the query type of the query
        :param str e: the end time of the query window in epoch milliseconds (null to use now)
        :param str p: the approximate maximum number of points to return (may not limit number of points exactly)
        :param bool i: whether series with only points that are outside of the query window will be returned (defaults to true)
        :param bool auto_events: whether events for sources included in the query will be automatically returned by the query
        :param str summarization: summarization strategy to use when bucketing points together
        :param bool list_mode: retrieve events more optimally displayed for a list
        :param bool strict: do not return points outside the query window [s;e), defaults to false
        :param str view: view of the query result, metric or histogram, defaults to metric
        :param bool include_obsolete_metrics: include metrics that have not been reporting recently, defaults to false
        :param bool sorted: sorts the output so that returned series are in order, defaults to false
        :param bool cached: whether the query cache is used, defaults to true
        :param list[str] dimension_tuples:
        :param bool use_raw_qk:
        :return: QueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q', 's', 'g', 'n', 'query_type', 'e', 'p', 'i', 'auto_events', 'summarization', 'list_mode', 'strict', 'view', 'include_obsolete_metrics', 'sorted', 'cached', 'dimension_tuples', 'use_raw_qk']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'q' is set
        if self.api_client.client_side_validation and ('q' not in params or
                                                       params['q'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `q` when calling `query_api`")  # noqa: E501
        # verify the required parameter 's' is set
        if self.api_client.client_side_validation and ('s' not in params or
                                                       params['s'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `s` when calling `query_api`")  # noqa: E501
        # verify the required parameter 'g' is set
        if self.api_client.client_side_validation and ('g' not in params or
                                                       params['g'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `g` when calling `query_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'n' in params:
            query_params.append(('n', params['n']))  # noqa: E501
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501
        if 'query_type' in params:
            query_params.append(('queryType', params['query_type']))  # noqa: E501
        if 's' in params:
            query_params.append(('s', params['s']))  # noqa: E501
        if 'e' in params:
            query_params.append(('e', params['e']))  # noqa: E501
        if 'g' in params:
            query_params.append(('g', params['g']))  # noqa: E501
        if 'p' in params:
            query_params.append(('p', params['p']))  # noqa: E501
        if 'i' in params:
            query_params.append(('i', params['i']))  # noqa: E501
        if 'auto_events' in params:
            query_params.append(('autoEvents', params['auto_events']))  # noqa: E501
        if 'summarization' in params:
            query_params.append(('summarization', params['summarization']))  # noqa: E501
        if 'list_mode' in params:
            query_params.append(('listMode', params['list_mode']))  # noqa: E501
        if 'strict' in params:
            query_params.append(('strict', params['strict']))  # noqa: E501
        if 'view' in params:
            query_params.append(('view', params['view']))  # noqa: E501
        if 'include_obsolete_metrics' in params:
            query_params.append(('includeObsoleteMetrics', params['include_obsolete_metrics']))  # noqa: E501
        if 'sorted' in params:
            query_params.append(('sorted', params['sorted']))  # noqa: E501
        if 'cached' in params:
            query_params.append(('cached', params['cached']))  # noqa: E501
        if 'dimension_tuples' in params:
            query_params.append(('dimensionTuples', params['dimension_tuples']))  # noqa: E501
            collection_formats['dimensionTuples'] = 'multi'  # noqa: E501
        if 'use_raw_qk' in params:
            query_params.append(('useRawQK', params['use_raw_qk']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/x-javascript; charset=UTF-8', 'application/javascript; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/chart/api', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_raw(self, metric, **kwargs):  # noqa: E501
        """Perform a raw data query against Wavefront servers that returns second granularity points grouped by tags  # noqa: E501

        An API to check if ingested points are as expected.  Points ingested within a single second are averaged when returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_raw(metric, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str metric: metric to query ingested points for (cannot contain wildcards) (required)
        :param str host: host to query ingested points for (cannot contain wildcards). host or source is equivalent, only one should be used.
        :param str source: source to query ingested points for (cannot contain wildcards). host or source is equivalent, only one should be used.
        :param int start_time: start time in epoch milliseconds (cannot be more than a day in the past) null to use an hour before endTime
        :param int end_time: end time in epoch milliseconds (cannot be more than a day in the past) null to use now
        :return: list[RawTimeseries]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_raw_with_http_info(metric, **kwargs)  # noqa: E501
        else:
            (data) = self.query_raw_with_http_info(metric, **kwargs)  # noqa: E501
            return data

    def query_raw_with_http_info(self, metric, **kwargs):  # noqa: E501
        """Perform a raw data query against Wavefront servers that returns second granularity points grouped by tags  # noqa: E501

        An API to check if ingested points are as expected.  Points ingested within a single second are averaged when returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_raw_with_http_info(metric, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str metric: metric to query ingested points for (cannot contain wildcards) (required)
        :param str host: host to query ingested points for (cannot contain wildcards). host or source is equivalent, only one should be used.
        :param str source: source to query ingested points for (cannot contain wildcards). host or source is equivalent, only one should be used.
        :param int start_time: start time in epoch milliseconds (cannot be more than a day in the past) null to use an hour before endTime
        :param int end_time: end time in epoch milliseconds (cannot be more than a day in the past) null to use now
        :return: list[RawTimeseries]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['metric', 'host', 'source', 'start_time', 'end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_raw" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'metric' is set
        if self.api_client.client_side_validation and ('metric' not in params or
                                                       params['metric'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `metric` when calling `query_raw`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'host' in params:
            query_params.append(('host', params['host']))  # noqa: E501
        if 'source' in params:
            query_params.append(('source', params['source']))  # noqa: E501
        if 'metric' in params:
            query_params.append(('metric', params['metric']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/chart/raw', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RawTimeseries]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class SourceLabelPair(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firing': 'int',
        'host': 'str',
        'label': 'str',
        'observed': 'int',
        'severity': 'str',
        'start_time': 'int',
        'tags': 'dict(str, str)'
    }

    attribute_map = {
        'firing': 'firing',
        'host': 'host',
        'label': 'label',
        'observed': 'observed',
        'severity': 'severity',
        'start_time': 'startTime',
        'tags': 'tags'
    }

    def __init__(self, firing=None, host=None, label=None, observed=None, severity=None, start_time=None, tags=None, _configuration=None):  # noqa: E501
        """SourceLabelPair - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._firing = None
        self._host = None
        self._label = None
        self._observed = None
        self._severity = None
        self._start_time = None
        self._tags = None
        self.discriminator = None

        if firing is not None:
            self.firing = firing
        if host is not None:
            self.host = host
        if label is not None:
            self.label = label
        if observed is not None:
            self.observed = observed
        if severity is not None:
            self.severity = severity
        if start_time is not None:
            self.start_time = start_time
        if tags is not None:
            self.tags = tags

    @property
    def firing(self):
        """Gets the firing of this SourceLabelPair.  # noqa: E501


        :return: The firing of this SourceLabelPair.  # noqa: E501
        :rtype: int
        """
        return self._firing

    @firing.setter
    def firing(self, firing):
        """Sets the firing of this SourceLabelPair.


        :param firing: The firing of this SourceLabelPair.  # noqa: E501
        :type: int
        """

        self._firing = firing

    @property
    def host(self):
        """Gets the host of this SourceLabelPair.  # noqa: E501

        Source (or host).  \"Source\" and \"host\" are synonyms in current versions of wavefront, but the host terminology is deprecated  # noqa: E501

        :return: The host of this SourceLabelPair.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this SourceLabelPair.

        Source (or host).  \"Source\" and \"host\" are synonyms in current versions of wavefront, but the host terminology is deprecated  # noqa: E501

        :param host: The host of this SourceLabelPair.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def label(self):
        """Gets the label of this SourceLabelPair.  # noqa: E501


        :return: The label of this SourceLabelPair.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this SourceLabelPair.


        :param label: The label of this SourceLabelPair.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def observed(self):
        """Gets the observed of this SourceLabelPair.  # noqa: E501


        :return: The observed of this SourceLabelPair.  # noqa: E501
        :rtype: int
        """
        return self._observed

    @observed.setter
    def observed(self, observed):
        """Sets the observed of this SourceLabelPair.


        :param observed: The observed of this SourceLabelPair.  # noqa: E501
        :type: int
        """

        self._observed = observed

    @property
    def severity(self):
        """Gets the severity of this SourceLabelPair.  # noqa: E501


        :return: The severity of this SourceLabelPair.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this SourceLabelPair.


        :param severity: The severity of this SourceLabelPair.  # noqa: E501
        :type: str
        """
        allowed_values = ["INFO", "SMOKE", "WARN", "SEVERE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                severity not in allowed_values):
            raise ValueError(
                "Invalid value for `severity` ({0}), must be one of {1}"  # noqa: E501
                .format(severity, allowed_values)
            )

        self._severity = severity

    @property
    def start_time(self):
        """Gets the start_time of this SourceLabelPair.  # noqa: E501

        Start time of this failing HLP, in epoch millis.  # noqa: E501

        :return: The start_time of this SourceLabelPair.  # noqa: E501
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SourceLabelPair.

        Start time of this failing HLP, in epoch millis.  # noqa: E501

        :param start_time: The start_time of this SourceLabelPair.  # noqa: E501
        :type: int
        """

        self._start_time = start_time

    @property
    def tags(self):
        """Gets the tags of this SourceLabelPair.  # noqa: E501


        :return: The tags of this SourceLabelPair.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this SourceLabelPair.


        :param tags: The tags of this SourceLabelPair.  # noqa: E501
        :type: dict(str, str)
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceLabelPair, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceLabelPair):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SourceLabelPair):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.webhook_api import WebhookApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestWebhookApi(unittest.TestCase):
    """WebhookApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.webhook_api.WebhookApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_webhook(self):
        """Test case for create_webhook

        Create a specific webhook  # noqa: E501
        """
        pass

    def test_delete_webhook(self):
        """Test case for delete_webhook

        Delete a specific webhook  # noqa: E501
        """
        pass

    def test_get_all_webhooks(self):
        """Test case for get_all_webhooks

        Get all webhooks for a customer  # noqa: E501
        """
        pass

    def test_get_webhook(self):
        """Test case for get_webhook

        Get a specific webhook  # noqa: E501
        """
        pass

    def test_update_webhook(self):
        """Test case for update_webhook

        Update a specific webhook  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Span(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annotations': 'list[dict(str, str)]',
        'duration_ms': 'int',
        'host': 'str',
        'name': 'str',
        'span_id': 'str',
        'start_ms': 'int',
        'trace_id': 'str'
    }

    attribute_map = {
        'annotations': 'annotations',
        'duration_ms': 'durationMs',
        'host': 'host',
        'name': 'name',
        'span_id': 'spanId',
        'start_ms': 'startMs',
        'trace_id': 'traceId'
    }

    def __init__(self, annotations=None, duration_ms=None, host=None, name=None, span_id=None, start_ms=None, trace_id=None, _configuration=None):  # noqa: E501
        """Span - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._annotations = None
        self._duration_ms = None
        self._host = None
        self._name = None
        self._span_id = None
        self._start_ms = None
        self._trace_id = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if duration_ms is not None:
            self.duration_ms = duration_ms
        if host is not None:
            self.host = host
        if name is not None:
            self.name = name
        if span_id is not None:
            self.span_id = span_id
        if start_ms is not None:
            self.start_ms = start_ms
        if trace_id is not None:
            self.trace_id = trace_id

    @property
    def annotations(self):
        """Gets the annotations of this Span.  # noqa: E501

        Annotations (key-value pairs) of this span  # noqa: E501

        :return: The annotations of this Span.  # noqa: E501
        :rtype: list[dict(str, str)]
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Span.

        Annotations (key-value pairs) of this span  # noqa: E501

        :param annotations: The annotations of this Span.  # noqa: E501
        :type: list[dict(str, str)]
        """

        self._annotations = annotations

    @property
    def duration_ms(self):
        """Gets the duration_ms of this Span.  # noqa: E501

        Span duration (in milliseconds)  # noqa: E501

        :return: The duration_ms of this Span.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms

    @duration_ms.setter
    def duration_ms(self, duration_ms):
        """Sets the duration_ms of this Span.

        Span duration (in milliseconds)  # noqa: E501

        :param duration_ms: The duration_ms of this Span.  # noqa: E501
        :type: int
        """

        self._duration_ms = duration_ms

    @property
    def host(self):
        """Gets the host of this Span.  # noqa: E501

        Source/Host of this span  # noqa: E501

        :return: The host of this Span.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this Span.

        Source/Host of this span  # noqa: E501

        :param host: The host of this Span.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def name(self):
        """Gets the name of this Span.  # noqa: E501

        Span name  # noqa: E501

        :return: The name of this Span.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Span.

        Span name  # noqa: E501

        :param name: The name of this Span.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def span_id(self):
        """Gets the span_id of this Span.  # noqa: E501

        Span ID  # noqa: E501

        :return: The span_id of this Span.  # noqa: E501
        :rtype: str
        """
        return self._span_id

    @span_id.setter
    def span_id(self, span_id):
        """Sets the span_id of this Span.

        Span ID  # noqa: E501

        :param span_id: The span_id of this Span.  # noqa: E501
        :type: str
        """

        self._span_id = span_id

    @property
    def start_ms(self):
        """Gets the start_ms of this Span.  # noqa: E501

        Span start time (in milliseconds)  # noqa: E501

        :return: The start_ms of this Span.  # noqa: E501
        :rtype: int
        """
        return self._start_ms

    @start_ms.setter
    def start_ms(self, start_ms):
        """Sets the start_ms of this Span.

        Span start time (in milliseconds)  # noqa: E501

        :param start_ms: The start_ms of this Span.  # noqa: E501
        :type: int
        """

        self._start_ms = start_ms

    @property
    def trace_id(self):
        """Gets the trace_id of this Span.  # noqa: E501

        Trace ID  # noqa: E501

        :return: The trace_id of this Span.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this Span.

        Trace ID  # noqa: E501

        :param trace_id: The trace_id of this Span.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Span, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Span):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Span):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Message(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attributes': 'dict(str, str)',
        'content': 'str',
        'display': 'str',
        'end_epoch_millis': 'int',
        'id': 'str',
        'read': 'bool',
        'scope': 'str',
        'severity': 'str',
        'source': 'str',
        'start_epoch_millis': 'int',
        'target': 'str',
        'title': 'str'
    }

    attribute_map = {
        'attributes': 'attributes',
        'content': 'content',
        'display': 'display',
        'end_epoch_millis': 'endEpochMillis',
        'id': 'id',
        'read': 'read',
        'scope': 'scope',
        'severity': 'severity',
        'source': 'source',
        'start_epoch_millis': 'startEpochMillis',
        'target': 'target',
        'title': 'title'
    }

    def __init__(self, attributes=None, content=None, display=None, end_epoch_millis=None, id=None, read=None, scope=None, severity=None, source=None, start_epoch_millis=None, target=None, title=None, _configuration=None):  # noqa: E501
        """Message - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._attributes = None
        self._content = None
        self._display = None
        self._end_epoch_millis = None
        self._id = None
        self._read = None
        self._scope = None
        self._severity = None
        self._source = None
        self._start_epoch_millis = None
        self._target = None
        self._title = None
        self.discriminator = None

        if attributes is not None:
            self.attributes = attributes
        self.content = content
        self.display = display
        self.end_epoch_millis = end_epoch_millis
        if id is not None:
            self.id = id
        if read is not None:
            self.read = read
        self.scope = scope
        self.severity = severity
        self.source = source
        self.start_epoch_millis = start_epoch_millis
        if target is not None:
            self.target = target
        self.title = title

    @property
    def attributes(self):
        """Gets the attributes of this Message.  # noqa: E501

        A string->string map of additional properties associated with this message  # noqa: E501

        :return: The attributes of this Message.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this Message.

        A string->string map of additional properties associated with this message  # noqa: E501

        :param attributes: The attributes of this Message.  # noqa: E501
        :type: dict(str, str)
        """

        self._attributes = attributes

    @property
    def content(self):
        """Gets the content of this Message.  # noqa: E501

        Message content  # noqa: E501

        :return: The content of this Message.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this Message.

        Message content  # noqa: E501

        :param content: The content of this Message.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def display(self):
        """Gets the display of this Message.  # noqa: E501

        The form of display for this message  # noqa: E501

        :return: The display of this Message.  # noqa: E501
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this Message.

        The form of display for this message  # noqa: E501

        :param display: The display of this Message.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display is None:
            raise ValueError("Invalid value for `display`, must not be `None`")  # noqa: E501
        allowed_values = ["BANNER", "TOASTER", "MODAL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                display not in allowed_values):
            raise ValueError(
                "Invalid value for `display` ({0}), must be one of {1}"  # noqa: E501
                .format(display, allowed_values)
            )

        self._display = display

    @property
    def end_epoch_millis(self):
        """Gets the end_epoch_millis of this Message.  # noqa: E501

        When this message will stop being displayed, in epoch millis  # noqa: E501

        :return: The end_epoch_millis of this Message.  # noqa: E501
        :rtype: int
        """
        return self._end_epoch_millis

    @end_epoch_millis.setter
    def end_epoch_millis(self, end_epoch_millis):
        """Sets the end_epoch_millis of this Message.

        When this message will stop being displayed, in epoch millis  # noqa: E501

        :param end_epoch_millis: The end_epoch_millis of this Message.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and end_epoch_millis is None:
            raise ValueError("Invalid value for `end_epoch_millis`, must not be `None`")  # noqa: E501

        self._end_epoch_millis = end_epoch_millis

    @property
    def id(self):
        """Gets the id of this Message.  # noqa: E501


        :return: The id of this Message.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Message.


        :param id: The id of this Message.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def read(self):
        """Gets the read of this Message.  # noqa: E501

        A derived field for whether the current user has read this message  # noqa: E501

        :return: The read of this Message.  # noqa: E501
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """Sets the read of this Message.

        A derived field for whether the current user has read this message  # noqa: E501

        :param read: The read of this Message.  # noqa: E501
        :type: bool
        """

        self._read = read

    @property
    def scope(self):
        """Gets the scope of this Message.  # noqa: E501

        The audience scope that this message should reach  # noqa: E501

        :return: The scope of this Message.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this Message.

        The audience scope that this message should reach  # noqa: E501

        :param scope: The scope of this Message.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and scope is None:
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501
        allowed_values = ["CLUSTER", "CUSTOMER", "USER"]  # noqa: E501
        if (self._configuration.client_side_validation and
                scope not in allowed_values):
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def severity(self):
        """Gets the severity of this Message.  # noqa: E501

        Message severity  # noqa: E501

        :return: The severity of this Message.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this Message.

        Message severity  # noqa: E501

        :param severity: The severity of this Message.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and severity is None:
            raise ValueError("Invalid value for `severity`, must not be `None`")  # noqa: E501
        allowed_values = ["MARKETING", "INFO", "WARN", "SEVERE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                severity not in allowed_values):
            raise ValueError(
                "Invalid value for `severity` ({0}), must be one of {1}"  # noqa: E501
                .format(severity, allowed_values)
            )

        self._severity = severity

    @property
    def source(self):
        """Gets the source of this Message.  # noqa: E501

        Message source.  System messages will com from 'system@wavefront.com'  # noqa: E501

        :return: The source of this Message.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this Message.

        Message source.  System messages will com from 'system@wavefront.com'  # noqa: E501

        :param source: The source of this Message.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def start_epoch_millis(self):
        """Gets the start_epoch_millis of this Message.  # noqa: E501

        When this message will begin to be displayed, in epoch millis  # noqa: E501

        :return: The start_epoch_millis of this Message.  # noqa: E501
        :rtype: int
        """
        return self._start_epoch_millis

    @start_epoch_millis.setter
    def start_epoch_millis(self, start_epoch_millis):
        """Sets the start_epoch_millis of this Message.

        When this message will begin to be displayed, in epoch millis  # noqa: E501

        :param start_epoch_millis: The start_epoch_millis of this Message.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and start_epoch_millis is None:
            raise ValueError("Invalid value for `start_epoch_millis`, must not be `None`")  # noqa: E501

        self._start_epoch_millis = start_epoch_millis

    @property
    def target(self):
        """Gets the target of this Message.  # noqa: E501

        For scope=CUSTOMER or scope=USER, the individual customer or user id  # noqa: E501

        :return: The target of this Message.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this Message.

        For scope=CUSTOMER or scope=USER, the individual customer or user id  # noqa: E501

        :param target: The target of this Message.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def title(self):
        """Gets the title of this Message.  # noqa: E501

        Title of this message  # noqa: E501

        :return: The title of this Message.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Message.

        Title of this message  # noqa: E501

        :param title: The title of this Message.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Message, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Message):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Message):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Sorting(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ascending': 'bool',
        'default': 'bool',
        'field': 'str'
    }

    attribute_map = {
        'ascending': 'ascending',
        'default': 'default',
        'field': 'field'
    }

    def __init__(self, ascending=None, default=None, field=None, _configuration=None):  # noqa: E501
        """Sorting - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ascending = None
        self._default = None
        self._field = None
        self.discriminator = None

        self.ascending = ascending
        if default is not None:
            self.default = default
        self.field = field

    @property
    def ascending(self):
        """Gets the ascending of this Sorting.  # noqa: E501

        Whether to sort ascending.  If undefined, sorting is not guaranteed  # noqa: E501

        :return: The ascending of this Sorting.  # noqa: E501
        :rtype: bool
        """
        return self._ascending

    @ascending.setter
    def ascending(self, ascending):
        """Sets the ascending of this Sorting.

        Whether to sort ascending.  If undefined, sorting is not guaranteed  # noqa: E501

        :param ascending: The ascending of this Sorting.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and ascending is None:
            raise ValueError("Invalid value for `ascending`, must not be `None`")  # noqa: E501

        self._ascending = ascending

    @property
    def default(self):
        """Gets the default of this Sorting.  # noqa: E501

        Whether this sort requests the default ranking order.  Ascending/descending does not matter if this attribute is true.  # noqa: E501

        :return: The default of this Sorting.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this Sorting.

        Whether this sort requests the default ranking order.  Ascending/descending does not matter if this attribute is true.  # noqa: E501

        :param default: The default of this Sorting.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def field(self):
        """Gets the field of this Sorting.  # noqa: E501

        The facet by which to sort  # noqa: E501

        :return: The field of this Sorting.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this Sorting.

        The facet by which to sort  # noqa: E501

        :param field: The field of this Sorting.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and field is None:
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Sorting, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Sorting):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Sorting):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.models.chart_source_query import ChartSourceQuery  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestChartSourceQuery(unittest.TestCase):
    """ChartSourceQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testChartSourceQuery(self):
        """Test ChartSourceQuery"""
        # FIXME: construct object with mandatory attributes with example values
        # model = wavefront_api_client.models.chart_source_query.ChartSourceQuery()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
